# Workbench Enterprise


The Workbench API and User Interfaces cover a broad set of AWS Machine Learning services and provide easy to use abstractions and visualizations of your AWS ML data. We offer a wide range of options to best fit your companies needs.


<figure style="width: 550px;">
<img alt="workbench_new_light" src="https://github.com/SuperCowPowers/workbench/assets/4806709/5f8b32a2-ed72-45f2-bd96-91b7bbbccff4">
<figcaption>Accelerate ML Pipeline development with an Enterprise License!</figcaption>
</figure>


|   | Free           | Enterprise: Lite  | Enterprise: Standard | Enterprise: Pro  |
|---|----------------|-------------|-----------------|------------------|
| **<a href="https://supercowpowers.github.io/workbench/api_classes/overview/" target="_blank">Python API</a>** | 🟢  | 🟢  | 🟢  | 🟢 |
| **<a href="https://supercowpowers.github.io/workbench/repl/" target="_blank">Workbench REPL</a>** | 🟢  | 🟢  | 🟢 | 🟢 |
| **<a href="https://supercowpowers.github.io/workbench/" target="_blank">Dashboard</a>** | 🟢  | 🟢  | 🟢 | 🟢 |
| **<a href="https://supercowpowers.github.io/workbench/aws_setup/core_stack/" target="_blank">AWS Onboarding</a>**      | ➖ | 🟢  | 🟢  | 🟢 |
| **<a href="https://supercowpowers.github.io/workbench/plugins/" target="_blank">Dashboard Plugins</a>** | ➖  | 🟢  | 🟢  | 🟢 |
| **<a href="https://supercowpowers.github.io/workbench/plugins/" target="_blank">Custom Pages</a>**        | ➖  | ➖  | 🟢  | 🟢 |
| **<a href="https://supercowpowers.github.io/workbench/enterprise/themes/" target="_blank">Themes</a>**              | ➖  | ➖  | 🟢  | 🟢 |
| **<a href="https://supercowpowers.github.io/workbench/api_classes/pipelines/" target="_blank">ML Pipelines</a>**        | ➖  | ➖  | ➖   | 🟢 |
| **<a href="https://supercowpowers.github.io/workbench/enterprise/project_branding/" target="_blank">Project Branding</a>** | ➖  | ➖  | ➖  | 🟢 |
| **Prioritized Feature Requests** | ➖| ➖| ➖ |🟢|
| **Pricing**            | ➖ | $1500*| $3000* | $4000* |

\*<small>*USD per month, includes AWS setup, support, and training: Everything needed to accelerate your AWS ML Development team. Interested in Data Science/Engineering consulting? We have top notch [Consultants](https://supercowpowers.github.io/workbench/enterprise/#data-engineeringscience-consulting) with a depth and breadth of AWS ML/DS/Engineering expertise.*</small>

## Try Workbench
We encourage new users to try out the **free** version, first. We offer support in our [Discord](https://discord.gg/WHAJuz8sw8) channel and our [Documentation](https://supercowpowers.github.io/workbench/) has instructions for how to get started with Workbench. So try it out and when you're ready to accelerate your AWS ML Adventure with an **Enterprise** licence contact us at [Workbench Sales](mailto:sales@supercowpowers.com)


## Data Engineering/Science Consulting

Alongside our Workbench Enterprise offerings, we provide comprehensive consulting services and domain expertise through our [Partnerships](https://www.supercowpowers.com/home#h.qau620rju99x). We specialize in **AWS Machine Learning Systems** and our extended team of Data Scientists and Engineers, have Masters and Ph.D. degrees in Computer Science, Chemistry, and Pharmacology. We also have a parntership with [Nomic Networks](https://nomicnetworks.com) to support our Network Security Clients.

Using **AWS** and **Workbench**, our experts are equipped to deliver tailored solutions that are focused on your project needs and deliverables. For more information please touch base and we'll set up a free initial consultation [Workbench Consulting](mailto:consulting@supercowpowers.com)

## Contact Us
Contact us on our [Discord](https://discord.gg/WHAJuz8sw8) channel, we're happy to answer any questions that you might have about **Workbench** and accelerating your AWS ML Pipelines. You can also send us email at [Workbench Info](mailto:workbench@supercowpowers.com) or  [Workbench Sales](mailto:sales@supercowpowers.com)
